import type { Provider } from 'injection-js';
import { ReflectiveInjector } from 'injection-js';
import type { InjectionKey } from 'vue';
export declare const InjectorKey: InjectionKey<ReflectiveInjector>;
declare module 'vue' {
    interface App {
        getStore(): any;
        getService(token: any): any;
    }
}
export interface ComponentOptions {
    /**
     * 依赖的服务
     */
    providers?: Provider[];
    /**
     * 排除掉的服务
     */
    exclude?: Provider[];
    /**
     * 自动分析依赖
     */
    autoResolveDeps?: boolean;
    /**
     * 此注入器是否作为全局的store
     */
    globalStore?: boolean;
    /**
     * option是否是稳定的，
     * 依赖解析只会在第一次的时候解析并且缓存下来，所以options如果是动态变化的，请标记
     */
    stable?: boolean;
}
export declare function Component(options?: ComponentOptions): ClassDecorator;
export declare function resolveComponent(target: {
    new (...args: []): any;
}): any;
export declare function resolveDependencies(inputs: Provider[]): Provider[];
/**
 * 获取当前的注射器，可用于外部使用
 */
export declare function getCurrentInjector(): ReflectiveInjector;
/** 手动创建当前注射器, 只能用在 setup 中 */
export declare function createCurrentInjector(providers: Provider[], exclude?: Provider[]): ReflectiveInjector;
/**
 * 从当前容器中获取服务
 * @param token
 * @param notFoundValue
 */
export declare function injectService<T extends {
    new (...args: any[]): any;
}>(token: T, notFoundValue?: any): InstanceType<T> | undefined;
